Thoth lab
---------

A laboratory providing helper functions for experiments on software stack
quality in Jupyter notebooks. This library is used in `project Thoth
<https://thoth-station.ninja>`_.

See `thoth-station/jupyter-notebook
<https://github.com/thoth-station/jupyter-notebook>`_ and
`thoth-station/notebooks <https://github.com/thoth-station/notebooks>`_ repos
for more information about usage of this library in `project Thoth
<https://thoth-station.ninja>`_.

Installation
============

This project is released on
`PyPI <https://pypi.org/project/thoth-lab>`_, so the latest release can be
installed via pip or `Pipenv <https://pipenv.readthedocs.io>`_ as shown below:

.. code-block:: console

  pipenv install thoth-lab
